@@ -77,7 +77,7 @@ public:
     /**
      * The quota root that will be modified.
      */
-    Q_REQUIRED_RESULT QByteArray root() const;
+    [[nodiscard]] QByteArray root() const;
 
 protected:
     void doStart() override;
@@ -85,4 +85,3 @@ protected:
 };
 
 }
-
